ShortcutMenuExtenderWindows class
- Inheritance
-
- Object
- PlatformInterface
- ShortcutMenuExtenderWindows
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
ShortcutMenuListener listener) → void -
getPlatformVersion(
) → Future< String?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
String key, {required String name, required String executable, bool useDefaultIcon = true}) → Future< void> -
removeListener(
ShortcutMenuListener listener) → void -
toString(
) → String -
A string representation of this object.
inherited
-
unregister(
String key) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
) → void - Registers the Windows implementation.